-- Define the folder containing your videos (replace with your folder path)
local folderPath = "/storage/emulated/0/"

-- Create a playlist to store video URIs
local playlist = ArrayList()

-- Function to recursively explore files in a folder
local function exploreFolder(folder)
    local files = folder.listFiles()
    if files then
        for i = 0, #files - 1 do
            local file = files[i]
            if file.isFile() then
                local fileName = file.getName()
                if fileName:match("%.mp4$") then
                    playlist.add(Uri.fromFile(file))
                end
            elseif file.isDirectory() then
                exploreFolder(file)
            end
        end
    end
end

-- Initialize the current index
local currentIndex = 0


-- Function to show all files in the playlist
local function showAllFiles()
    local fileList = {}
    for i = 0, #playlist() - 1 do
        fileList[#fileList + 1] = playlist.get(i).getPath()
    end;
    local fileListText = table.concat(fileList, "\n")
    showAlert("All Files", fileListText)
end;

-- Function to loop to the next video or back to the first when reaching the last
local function nextOrLoop()
    currentIndex = (currentIndex + 1) % playlist.size()
    videoView.setVideoURI(playlist.get(currentIndex))
    videoView.start()
    playPauseButton.setText("Pause")
    isPlaying = true
end;

-- Function to loop to the previous video or back to the last when reaching the first
local function prevOrLoop()
    currentIndex = (currentIndex - 1 + playlist.size()) % playlist.size()
    videoView.setVideoURI(playlist.get(currentIndex))
    videoView.start()
    playPauseButton.setText("Pause")
    isPlaying = true
end

;-- Function to delete the currently playing file with a confirmation dialog
local function deleteCurrentFile()
    if currentIndex >= 0 and currentIndex < playlist.size() then
        local fileToDelete = File(playlist.get(currentIndex).getPath())
        if fileToDelete.exists() then
            local confirmDeleteDialog = AlertDialog.Builder(activity)
            confirmDeleteDialog.setTitle("Confirm Delete")
            confirmDeleteDialog.setMessage("Are you sure you want to delete this file?")
            confirmDeleteDialog.setPositiveButton("Delete", DialogInterface.OnClickListener {
                onClick = function(dialog, which)
                    fileToDelete.delete()
                    playlist.remove(currentIndex)
                    if currentIndex >= playlist.size() then
                        currentIndex = playlist.size() - 1
                    end;
                    if playlist.size() > 0 then
                        videoView.setVideoURI(playlist.get(currentIndex))
                        videoView.start()
                        playPauseButton.setText("Pause")
                        isPlaying = true
                    else
                        -- No more videos in the playlist, clear the videoView
                        videoView.stopPlayback()
                        playPauseButton.setText("Play")
                        isPlaying = false
                    end
                end;
            })
            confirmDeleteDialog.setNegativeButton("Cancel", DialogInterface.OnClickListener {
                onClick = function(dialog, which)
                    dialog.dismiss()
                end;
            })
            confirmDeleteDialog.show()
        end
;    end
end;
